aboutsummaryrefslogtreecommitdiffstats
path: root/src/modules
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules')
-rw-r--r--src/modules/addon/AddonFunctions.h2
-rw-r--r--src/modules/context/libkvicontext.cpp8
-rw-r--r--src/modules/dcc/DccCanvasWindow.cpp4
-rw-r--r--src/modules/dcc/DccVideoWindow.cpp34
-rw-r--r--src/modules/dcc/DccVoiceCodec.cpp8
-rw-r--r--src/modules/dcc/DccVoiceGsmCodec.cpp14
-rw-r--r--src/modules/dcc/DccVoiceWindow.h6
-rw-r--r--src/modules/dcc/DccWindow.h2
-rw-r--r--src/modules/dcc/canvaswidget.cpp10
-rw-r--r--src/modules/editor/ScriptEditorImplementation.h2
-rw-r--r--src/modules/file/libkvifile.cpp2
-rw-r--r--src/modules/filetransferwindow/FileTransferWindow.cpp2
-rw-r--r--src/modules/filetransferwindow/FileTransferWindow.h2
-rw-r--r--src/modules/ident/libkviident.h2
-rw-r--r--src/modules/list/ListWindow.h2
-rw-r--r--src/modules/mediaplayer/MpAmipInterface.cpp8
-rw-r--r--src/modules/mediaplayer/MpInterface.h2
-rw-r--r--src/modules/mediaplayer/MpWinampInterface.cpp23
-rw-r--r--src/modules/mediaplayer/winamp.cpp2
-rw-r--r--src/modules/my/libkvimy.cpp2
-rw-r--r--src/modules/objects/KvsObject_painter.cpp2
-rw-r--r--src/modules/objects/KvsObject_pixmap.h4
-rw-r--r--src/modules/objects/KvsObject_tableWidget.h2
-rw-r--r--src/modules/objects/object_macros.h4
-rw-r--r--src/modules/options/OptionsInstanceManager.cpp2
-rw-r--r--src/modules/options/OptionsWidget_message.h4
-rwxr-xr-xsrc/modules/options/mkcreateinstanceproc.sh14
-rw-r--r--src/modules/popupeditor/PopupEditorWindow.h2
-rw-r--r--src/modules/reguser/RegisteredUsersDialog.h4
-rw-r--r--src/modules/reguser/RegistrationWizard.h2
-rw-r--r--src/modules/rijndael/Rijndael.h12
-rw-r--r--src/modules/setup/SetupWizard.cpp6
-rw-r--r--src/modules/sharedfileswindow/SharedFilesWindow.h2
-rw-r--r--src/modules/snd/libkvisnd.cpp4
-rw-r--r--src/modules/term/TermWidget.cpp14
-rw-r--r--src/modules/term/TermWindow.cpp2
-rw-r--r--src/modules/theme/ThemeFunctions.h4
-rw-r--r--src/modules/theme/WebThemeInterfaceDialog.h2
-rw-r--r--src/modules/torrent/TorrentInterface.h2
-rw-r--r--src/modules/url/libkviurl.h2
-rw-r--r--src/modules/window/UserWindow.h2
41 files changed, 114 insertions, 115 deletions
diff --git a/src/modules/addon/AddonFunctions.h b/src/modules/addon/AddonFunctions.h
index 6d4d9cae2..27071dc56 100644
--- a/src/modules/addon/AddonFunctions.h
+++ b/src/modules/addon/AddonFunctions.h
@@ -50,7 +50,7 @@ namespace AddonFunctions
bool checkDirTree(const QString & szDirPath, QString * pszError);
bool pack(AddonInfo & info, QString & szError);
bool notAValidAddonPackage(QString & szError);
- bool installAddonPackage(const QString & szAddonPackageFileName, QString & szError, QWidget * pDialogParent = 0);
+ bool installAddonPackage(const QString & szAddonPackageFileName, QString & szError, QWidget * pDialogParent = nullptr);
QString createRandomDir();
}
diff --git a/src/modules/context/libkvicontext.cpp b/src/modules/context/libkvicontext.cpp
index ef575d681..11eaaf93c 100644
--- a/src/modules/context/libkvicontext.cpp
+++ b/src/modules/context/libkvicontext.cpp
@@ -51,16 +51,16 @@
KVSM_PARAMETERS_BEGIN(c) \
KVSM_PARAMETER("irc_context_id", KVS_PT_UINT, KVS_PF_OPTIONAL, iContextId) \
KVSM_PARAMETERS_END(c) \
- KviConsoleWindow * pConsole = NULL; \
+ KviConsoleWindow * pConsole = nullptr; \
if(c->parameterCount() > 0) \
pConsole = g_pApp->findConsole(iContextId); \
else \
pConsole = c->window()->console();
#define GET_CONNECTION_FROM_STANDARD_PARAMS \
- GET_CONSOLE_FROM_STANDARD_PARAMS \
- KviIrcConnection * pConnection = NULL; \
- if(pConsole) \
+ GET_CONSOLE_FROM_STANDARD_PARAMS \
+ KviIrcConnection * pConnection = nullptr; \
+ if(pConsole) \
pConnection = pConsole->context()->connection();
#define STANDARD_IRC_CONNECTION_TARGET_PARAMETER(_fncName, _setCall) \
diff --git a/src/modules/dcc/DccCanvasWindow.cpp b/src/modules/dcc/DccCanvasWindow.cpp
index 89c71f55b..e2adee2a4 100644
--- a/src/modules/dcc/DccCanvasWindow.cpp
+++ b/src/modules/dcc/DccCanvasWindow.cpp
@@ -114,7 +114,7 @@ DccCanvasWindow::DccCanvasWindow(DccDescriptor * dcc, const char * name)
output(KVI_OUT_DCCMSG, __tr2qs_ctx("Contacting host %Q on port %Q", "dcc"), &(dcc->szIp), &(dcc->szPort));
}
- // m_pSlaveThread = 0;
+ // m_pSlaveThread = nullptr;
}
DccCanvasWindow::~DccCanvasWindow()
@@ -124,7 +124,7 @@ DccCanvasWindow::~DccCanvasWindow()
// {
// m_pSlaveThread->terminate();
// delete m_pSlaveThread;
- // m_pSlaveThread = 0;
+ // m_pSlaveThread = nullptr;
// }
KviThreadManager::killPendingEvents(this);
// delete m_pDescriptor;
diff --git a/src/modules/dcc/DccVideoWindow.cpp b/src/modules/dcc/DccVideoWindow.cpp
index 3497843ba..963a30b36 100644
--- a/src/modules/dcc/DccVideoWindow.cpp
+++ b/src/modules/dcc/DccVideoWindow.cpp
@@ -258,7 +258,7 @@ bool DccVideoThread::handleIncomingData(KviDccThreadIncomingData * data, bool bC
// no more data in the buffer
KVI_ASSERT(data->iLen == 0);
KviMemory::free(data->buffer);
- data->buffer = end = aux = 0;
+ data->buffer = end = aux = nullptr;
}
postEvent(parent(), e);
}
@@ -280,7 +280,7 @@ bool DccVideoThread::handleIncomingData(KviDccThreadIncomingData * data, bool bC
e->setData(s);
data->iLen = 0;
KviMemory::free(data->buffer);
- data->buffer = 0;
+ data->buffer = nullptr;
postEvent(parent(), e);
}
}
@@ -395,8 +395,8 @@ DccVideoWindow::DccVideoWindow(DccDescriptor * dcc, const char * name)
: DccWindow(KviWindow::DccVideo, name, dcc)
{
m_pDescriptor = dcc;
- m_pSlaveThread = 0;
- m_pszTarget = 0;
+ m_pSlaveThread = nullptr;
+ m_pszTarget = nullptr;
m_pButtonBox = new KviTalHBox(this);
@@ -500,51 +500,51 @@ DccVideoWindow::~DccVideoWindow()
if(m_pInVideoLabel)
{
delete m_pInVideoLabel;
- m_pInVideoLabel = 0;
+ m_pInVideoLabel = nullptr;
}
if(m_pCameraView)
{
delete m_pCameraView;
- m_pCameraView = 0;
+ m_pCameraView = nullptr;
}
if(m_pCameraImage)
{
delete m_pCameraImage;
- m_pCameraImage = 0;
+ m_pCameraImage = nullptr;
}
if(m_pCamera)
{
delete m_pCamera;
- m_pCamera = 0;
+ m_pCamera = nullptr;
}
if(m_pCDevices)
{
delete m_pCDevices;
- m_pCDevices = 0;
+ m_pCDevices = nullptr;
}
if(m_pCInputs)
{
delete m_pCInputs;
- m_pCInputs = 0;
+ m_pCInputs = nullptr;
}
if(m_pCStandards)
{
delete m_pCStandards;
- m_pCStandards = 0;
+ m_pCStandards = nullptr;
}
if(m_pVideoLabel[0])
{
delete m_pVideoLabel[2];
delete m_pVideoLabel[1];
delete m_pVideoLabel[0];
- m_pVideoLabel[2] = 0;
- m_pVideoLabel[1] = 0;
- m_pVideoLabel[0] = 0;
+ m_pVideoLabel[2] = nullptr;
+ m_pVideoLabel[1] = nullptr;
+ m_pVideoLabel[0] = nullptr;
}
if(m_pLayout)
{
delete m_pLayout;
- m_pLayout = 0;
+ m_pLayout = nullptr;
}
g_pDccBroker->unregisterDccWindow(this);
@@ -553,7 +553,7 @@ DccVideoWindow::~DccVideoWindow()
{
m_pSlaveThread->terminate();
delete m_pSlaveThread;
- m_pSlaveThread = 0;
+ m_pSlaveThread = nullptr;
}
KviThreadManager::killPendingEvents(this);
@@ -561,7 +561,7 @@ DccVideoWindow::~DccVideoWindow()
if(m_pszTarget)
{
delete m_pszTarget;
- m_pszTarget = 0;
+ m_pszTarget = nullptr;
}
}
diff --git a/src/modules/dcc/DccVoiceCodec.cpp b/src/modules/dcc/DccVoiceCodec.cpp
index 1028e7c72..5e70d176c 100644
--- a/src/modules/dcc/DccVoiceCodec.cpp
+++ b/src/modules/dcc/DccVoiceCodec.cpp
@@ -263,19 +263,19 @@ DccVideoTheoraCodec::DccVideoTheoraCodec()
: DccVideoCodec()
{
m_szName = "theora";
- m_pEncoder = 0;
- m_pDecoder = 0;
+ m_pEncoder = nullptr;
+ m_pDecoder = nullptr;
}
DccVideoTheoraCodec::~DccVideoTheoraCodec()
{
if(m_pEncoder)
delete m_pEncoder;
- m_pEncoder = 0;
+ m_pEncoder = nullptr;
if(m_pDecoder)
delete m_pDecoder;
- m_pDecoder = 0;
+ m_pDecoder = nullptr;
}
void DccVideoTheoraCodec::encodeVideo(KviDataBuffer * videoSignal, KviDataBuffer * stream)
diff --git a/src/modules/dcc/DccVoiceGsmCodec.cpp b/src/modules/dcc/DccVoiceGsmCodec.cpp
index e2a23bb4e..3a7929b3d 100644
--- a/src/modules/dcc/DccVoiceGsmCodec.cpp
+++ b/src/modules/dcc/DccVoiceGsmCodec.cpp
@@ -33,12 +33,12 @@
#define GSM_UNPACKED_FRAME_SIZE_IN_BYTES 320
#define GSM_UNPACKED_FRAME_SIZE_IN_SHORTS 160
-void * (*gsm_session_create)() = 0;
-void (*gsm_session_destroy)(void *) = 0;
-void (*gsm_session_encode)(void *, short *, unsigned char *) = 0;
-int (*gsm_session_decode)(void *, unsigned char *, short *) = 0;
+void * (*gsm_session_create)() = nullptr;
+void (*gsm_session_destroy)(void *) = nullptr;
+void (*gsm_session_encode)(void *, short *, unsigned char *) = nullptr;
+int (*gsm_session_decode)(void *, unsigned char *, short *) = nullptr;
-void * g_pGSMCodecLibraryHandle = 0;
+void * g_pGSMCodecLibraryHandle = nullptr;
bool kvi_gsm_codec_init()
{
@@ -57,7 +57,7 @@ bool kvi_gsm_codec_init()
if(!(gsm_session_create && gsm_session_destroy && gsm_session_encode && gsm_session_decode))
{
dlclose(g_pGSMCodecLibraryHandle);
- g_pGSMCodecLibraryHandle = 0;
+ g_pGSMCodecLibraryHandle = nullptr;
return false;
}
return true;
@@ -68,7 +68,7 @@ void kvi_gsm_codec_done()
if(g_pGSMCodecLibraryHandle)
{
dlclose(g_pGSMCodecLibraryHandle);
- g_pGSMCodecLibraryHandle = 0;
+ g_pGSMCodecLibraryHandle = nullptr;
}
}
diff --git a/src/modules/dcc/DccVoiceWindow.h b/src/modules/dcc/DccVoiceWindow.h
index 5c2139245..f0f7dc898 100644
--- a/src/modules/dcc/DccVoiceWindow.h
+++ b/src/modules/dcc/DccVoiceWindow.h
@@ -188,7 +188,7 @@ public:
KviVoiceParty::KviVoiceParty(const QString &szNick,const QString &szIp,unsigned short uPort)
: m_szIp(szIp), m_uPort(uPort), m_szNick(szNick)
{
- m_pChildrenTree = 0;
+ m_pChildrenTree = nullptr;
}
KviVoiceParty::~KviVoiceParty()
@@ -241,8 +241,8 @@ KviVoiceLink::KviVoiceLink(KviVoiceParty * pRemoteParty)
{
KviQString::sprintf("%Q:%u",&(pRemoteParty->nick()),pRemoteParty->port());
m_pRemoteParty = pRemoteParty;
- m_pAudioEncoder = 0;
- m_pAudioDecoder = 0;
+ m_pAudioEncoder = nullptr;
+ m_pAudioDecoder = nullptr;
}
KviVoiceLink::~KviVoiceLink()
diff --git a/src/modules/dcc/DccWindow.h b/src/modules/dcc/DccWindow.h
index 31a4710fd..483f1ad43 100644
--- a/src/modules/dcc/DccWindow.h
+++ b/src/modules/dcc/DccWindow.h
@@ -45,7 +45,7 @@ protected:
public:
DccDescriptor * descriptor() { return m_pDescriptor; };
const DccMarshal * marshal() { return m_pMarshal; };
- virtual DccThread * getSlaveThread() { return 0; };
+ virtual DccThread * getSlaveThread() { return nullptr; }
virtual KviWindow * dccMarshalOutputWindow();
virtual const char * dccMarshalOutputContextString();
};
diff --git a/src/modules/dcc/canvaswidget.cpp b/src/modules/dcc/canvaswidget.cpp
index 8da7a0204..03d69ac58 100644
--- a/src/modules/dcc/canvaswidget.cpp
+++ b/src/modules/dcc/canvaswidget.cpp
@@ -466,7 +466,7 @@ KviCanvasView::KviCanvasView(QCanvas * c, DccCanvasWidget * cw, QWidget * par)
m_pCanvasWidget = cw;
m_state = Idle;
m_dragMode = None;
- m_pSelectedItem = 0;
+ m_pSelectedItem = nullptr;
viewport()->setMouseTracking(true);
}
@@ -562,7 +562,7 @@ static void calcPolygonPoints(QPointArray & pnts, unsigned int nVertices)
void KviCanvasView::insertObjectAt(const QPoint & pnt, ObjectType o)
{
- QCanvasItem * r = 0;
+ QCanvasItem * r = nullptr;
switch(o)
{
@@ -655,7 +655,7 @@ void KviCanvasView::clearSelection()
if(!m_pSelectedItem)
return;
m_pSelectedItem->setSelected(false);
- m_pSelectedItem = 0;
+ m_pSelectedItem = nullptr;
m_pCanvasWidget->m_pPropertiesWidget->editItem(0);
}
@@ -1297,7 +1297,7 @@ QWidget * KviVariantTableItem::createEditor() const
default:
break;
}
- return 0;
+ return nullptr;
}
void KviVariantTableItem::setContentFromEditor(QWidget * w)
@@ -1429,7 +1429,7 @@ void KviCanvasItemPropertiesWidget::editItem(QCanvasItem * it)
return;
}
- QMap<QString, QVariant> * m = 0;
+ QMap<QString, QVariant> * m = nullptr;
switch(KVI_CANVAS_RTTI_CONTROL_TYPE(it))
{
diff --git a/src/modules/editor/ScriptEditorImplementation.h b/src/modules/editor/ScriptEditorImplementation.h
index 91baf4303..35ee28ba9 100644
--- a/src/modules/editor/ScriptEditorImplementation.h
+++ b/src/modules/editor/ScriptEditorImplementation.h
@@ -202,7 +202,7 @@ class ScriptEditorReplaceDialog final : public QDialog
{
Q_OBJECT
public:
- ScriptEditorReplaceDialog(QWidget * parent = 0, const QString & szName = QString());
+ ScriptEditorReplaceDialog(QWidget * parent = nullptr, const QString & szName = QString());
public:
QLineEdit * m_pFindLineEdit;
diff --git a/src/modules/file/libkvifile.cpp b/src/modules/file/libkvifile.cpp
index 9025ad33d..2ff800b5f 100644
--- a/src/modules/file/libkvifile.cpp
+++ b/src/modules/file/libkvifile.cpp
@@ -1489,7 +1489,7 @@ static bool file_kvs_fnc_diskSpace(KviKvsModuleFunctionCall * c)
// this for win
#if defined(COMPILE_ON_WINDOWS) || defined(COMPILE_ON_MINGW)
ULARGE_INTEGER free, total;
- if (GetDiskFreeSpaceEx(szPath.toStdWString().c_str(), NULL, &total, &free) == 0) {
+ if (GetDiskFreeSpaceEx(szPath.toStdWString().c_str(), nullptr, &total, &free) == 0) {
c->warning(__tr2qs("An error occurred retrieving the amount of free space in '%Q'"), &szPath);
return true;
}
diff --git a/src/modules/filetransferwindow/FileTransferWindow.cpp b/src/modules/filetransferwindow/FileTransferWindow.cpp
index 70dfcd9c3..03328ecd5 100644
--- a/src/modules/filetransferwindow/FileTransferWindow.cpp
+++ b/src/modules/filetransferwindow/FileTransferWindow.cpp
@@ -666,7 +666,7 @@ void FileTransferWindow::openLocalFile()
if(tmp.isEmpty())
return;
tmp.replace("/", "\\");
- ShellExecute(0, TEXT("open"), tmp.toStdWString().c_str(), NULL, NULL, SW_SHOWNORMAL); //You have to link the shell32.lib
+ ShellExecute(0, TEXT("open"), tmp.toStdWString().c_str(), nullptr, nullptr, SW_SHOWNORMAL); //You have to link the shell32.lib
#else
// G&N end
#ifdef COMPILE_KDE4_SUPPORT
diff --git a/src/modules/filetransferwindow/FileTransferWindow.h b/src/modules/filetransferwindow/FileTransferWindow.h
index 89839c674..9c13d1c0c 100644
--- a/src/modules/filetransferwindow/FileTransferWindow.h
+++ b/src/modules/filetransferwindow/FileTransferWindow.h
@@ -81,7 +81,7 @@ class FileTransferItemDelegate : public KviTalIconAndRichTextItemDelegate
{
Q_OBJECT
public:
- FileTransferItemDelegate(QAbstractItemView * pWidget = 0)
+ FileTransferItemDelegate(QAbstractItemView * pWidget = nullptr)
: KviTalIconAndRichTextItemDelegate(pWidget){};
~FileTransferItemDelegate(){};
QSize sizeHint(const QStyleOptionViewItem & option, const QModelIndex & index) const;
diff --git a/src/modules/ident/libkviident.h b/src/modules/ident/libkviident.h
index 613222ab5..2aa573402 100644
--- a/src/modules/ident/libkviident.h
+++ b/src/modules/ident/libkviident.h
@@ -85,7 +85,7 @@ public:
void run() override;
protected:
- void postMessage(const char * message, KviIdentRequest * r, const char * szAux = 0);
+ void postMessage(const char * message, KviIdentRequest * r, const char * szAux = nullptr);
};
#endif //_LIBKVIIDENT_H_
diff --git a/src/modules/list/ListWindow.h b/src/modules/list/ListWindow.h
index 30da96db0..0eba68571 100644
--- a/src/modules/list/ListWindow.h
+++ b/src/modules/list/ListWindow.h
@@ -44,7 +44,7 @@ class KviThemedLineEdit;
class ChannelTreeWidgetItemDelegate : public QItemDelegate
{
public:
- ChannelTreeWidgetItemDelegate(QTreeWidget * pWidget = 0);
+ ChannelTreeWidgetItemDelegate(QTreeWidget * pWidget = nullptr);
~ChannelTreeWidgetItemDelegate();
void paint(QPainter * pPainter, const QStyleOptionViewItem & option, const QModelIndex & index) const;
QSize sizeHint(const QStyleOptionViewItem & option, const QModelIndex & index) const;
diff --git a/src/modules/mediaplayer/MpAmipInterface.cpp b/src/modules/mediaplayer/MpAmipInterface.cpp
index 640c9fc8f..2514ba52b 100644
--- a/src/modules/mediaplayer/MpAmipInterface.cpp
+++ b/src/modules/mediaplayer/MpAmipInterface.cpp
@@ -51,7 +51,7 @@ enum ac_ErrorCode
#define AC_BUFFER_SIZE 2048
-static HINSTANCE amip_dll = NULL;
+static HINSTANCE amip_dll = nullptr;
#define MP_AC_DYNPTR(__rettype, __func, __args) \
typedef __rettype(CALLBACK * lp_##__func)(__args); \
@@ -94,7 +94,7 @@ static bool loadAmipDll()
static QTextCodec * mediaplayer_get_codec()
{
- QTextCodec * pCodec = 0;
+ QTextCodec * pCodec = nullptr;
pCodec = QTextCodec::codecForName(KVI_OPTION_STRING(KviOption_stringWinampTextEncoding).toUtf8());
if(!pCodec)
@@ -120,7 +120,7 @@ MpAmipInterface::MpAmipInterface()
bool res = loadAmipDll();
if(!res)
{
- amip_dll = NULL;
+ amip_dll = nullptr;
return;
}
ac_init(AC_START_CLIENT);
@@ -133,7 +133,7 @@ MpAmipInterface::~MpAmipInterface()
return;
ac_uninit();
FreeLibrary(amip_dll);
- amip_dll = NULL;
+ amip_dll = nullptr;
}
int MpAmipInterface::detect(bool bStart)
diff --git a/src/modules/mediaplayer/MpInterface.h b/src/modules/mediaplayer/MpInterface.h
index a82016b24..69ec610bb 100644
--- a/src/modules/mediaplayer/MpInterface.h
+++ b/src/modules/mediaplayer/MpInterface.h
@@ -219,7 +219,7 @@ public:
_interfaceclass##Descriptor::_interfaceclass##Descriptor() \
: MpInterfaceDescriptor() \
{ \
- m_pInstance = 0; \
+ m_pInstance = nullptr; \
m_szName = _name; \
m_szDescription = _description; \
} \
diff --git a/src/modules/mediaplayer/winamp.cpp b/src/modules/mediaplayer/winamp.cpp
index 4bb67b8e5..0d701558a 100644
--- a/src/modules/mediaplayer/winamp.cpp
+++ b/src/modules/mediaplayer/winamp.cpp
@@ -72,7 +72,7 @@ winampGeneralPurposePlugin plugin = {
#define KVIRC_WM_USER_CHECK 13123
#define KVIRC_WM_USER_CHECK_REPLY 13124
-void * lpWndProcOld = 0;
+void * lpWndProcOld = nullptr;
char szBuffer[4096];
diff --git a/src/modules/my/libkvimy.cpp b/src/modules/my/libkvimy.cpp
index 43ea72c1c..822559314 100644
--- a/src/modules/my/libkvimy.cpp
+++ b/src/modules/my/libkvimy.cpp
@@ -37,7 +37,7 @@ Idle * g_pIdle;
#define GET_KVS_CONSOLE \
kvs_uint_t uiWnd; \
- KviConsoleWindow * wnd = 0; \
+ KviConsoleWindow * wnd = nullptr; \
KVSM_PARAMETERS_BEGIN(c) \
KVSM_PARAMETER("context_id", KVS_PT_UINT, KVS_PF_OPTIONAL, uiWnd) \
KVSM_PARAMETERS_END(c) \
diff --git a/src/modules/objects/KvsObject_painter.cpp b/src/modules/objects/KvsObject_painter.cpp
index aa2e7b548..4918253d3 100644
--- a/src/modules/objects/KvsObject_painter.cpp
+++ b/src/modules/objects/KvsObject_painter.cpp
@@ -2110,7 +2110,7 @@ KVSO_CLASS_FUNCTION(painter, drawPath)
CHECK_INTERNAL_POINTER(m_pPainter)
m_pPainter->drawPath(*m_pPainterPath);
//delete m_pPainterPath;
- //m_pPainterPath=0;
+ //m_pPainterPath=nullptr;
return true;
}
diff --git a/src/modules/objects/KvsObject_pixmap.h b/src/modules/objects/KvsObject_pixmap.h
index 35874f1f6..63b4de5c4 100644
--- a/src/modules/objects/KvsObject_pixmap.h
+++ b/src/modules/objects/KvsObject_pixmap.h
@@ -58,7 +58,7 @@ public:
{
*m_pImage = m_pPixmap->toImage();
delete m_pPixmap;
- m_pPixmap = 0;
+ m_pPixmap = nullptr;
}
}
m_currentType = Image;
@@ -75,7 +75,7 @@ public:
{
*m_pPixmap = m_pPixmap->fromImage(*m_pImage);
delete m_pImage;
- m_pImage = 0;
+ m_pImage = nullptr;
}
}
m_currentType = Pixmap;
diff --git a/src/modules/objects/KvsObject_tableWidget.h b/src/modules/objects/KvsObject_tableWidget.h
index 559f7f724..416e78f9b 100644
--- a/src/modules/objects/KvsObject_tableWidget.h
+++ b/src/modules/objects/KvsObject_tableWidget.h
@@ -39,7 +39,7 @@ class KvsObject_tableWidget;
class KviCellItemDelegate : public QItemDelegate
{
public:
- KviCellItemDelegate(QAbstractItemView * pWidget = 0, KvsObject_tableWidget * pParent = 0);
+ KviCellItemDelegate(QAbstractItemView * pWidget = nullptr, KvsObject_tableWidget * pParent = nullptr);
~KviCellItemDelegate();
protected:
diff --git a/src/modules/objects/object_macros.h b/src/modules/objects/object_macros.h
index c6e92c9dc..28525e7d0 100644
--- a/src/modules/objects/object_macros.h
+++ b/src/modules/objects/object_macros.h
@@ -58,7 +58,7 @@
g_pKvs##__className##Class->registerStandardFalseReturnFunctionHandler(__szName);
#define KVSO_BEGIN_REGISTERCLASS(__className, __stringName, __baseClass) \
- static KviKvsObjectClass * g_pKvs##__className##Class = 0; \
+ static KviKvsObjectClass * g_pKvs##__className##Class = nullptr; \
static KviKvsObject * kvs_##__className##_createInstance(KviKvsObjectClass * pClass, KviKvsObject * pParent, const QString & szName) \
{ \
return new __className(pClass, pParent, szName); \
@@ -66,7 +66,7 @@
void __className::unregisterSelf() \
{ \
delete g_pKvs##__className##Class; \
- g_pKvs##__className##Class = 0; \
+ g_pKvs##__className##Class = nullptr; \
} \
void __className::registerSelf() \
{ \
diff --git a/src/modules/options/OptionsInstanceManager.cpp b/src/modules/options/OptionsInstanceManager.cpp
index 41ed5ae04..36291b24a 100644
--- a/src/modules/options/OptionsInstanceManager.cpp
+++ b/src/modules/options/OptionsInstanceManager.cpp
@@ -3712,7 +3712,7 @@ KviOptionsWidget * OptionsInstanceManager::getInstance(OptionsWidgetInstanceEntr
QWidget * pOldPar = (QWidget *)pEntry->pWidget->parent();
pEntry->pWidget->setParent(pPar);
pOldPar->deleteLater();
- pEntry->pWidget = 0;
+ pEntry->pWidget = nullptr;
}
}
#endif
diff --git a/src/modules/options/OptionsWidget_message.h b/src/modules/options/OptionsWidget_message.h
index fb65be65d..9652a7b0c 100644
--- a/src/modules/options/OptionsWidget_message.h
+++ b/src/modules/options/OptionsWidget_message.h
@@ -113,7 +113,7 @@ class MessageListWidgetItemDelegate : public QItemDelegate
{
Q_OBJECT
public:
- MessageListWidgetItemDelegate(QAbstractItemView * pWidget = 0)
+ MessageListWidgetItemDelegate(QAbstractItemView * pWidget = nullptr)
: QItemDelegate(pWidget){};
~MessageListWidgetItemDelegate(){};
void paint(QPainter * p, const QStyleOptionViewItem & opt, const QModelIndex & index) const;
@@ -151,7 +151,7 @@ class MessageColorListWidgetItemDelegate : public QItemDelegate
{
Q_OBJECT
public:
- MessageColorListWidgetItemDelegate(QAbstractItemView * pWidget = 0)
+ MessageColorListWidgetItemDelegate(QAbstractItemView * pWidget = nullptr)
: QItemDelegate(pWidget){};
~MessageColorListWidgetItemDelegate(){};
void paint(QPainter * p, const QStyleOptionViewItem & opt, const QModelIndex & index) const;
diff --git a/src/modules/options/mkcreateinstanceproc.sh b/src/modules/options/mkcreateinstanceproc.sh
index 858f6cd63..d1c33c518 100755
--- a/src/modules/options/mkcreateinstanceproc.sh
+++ b/src/modules/options/mkcreateinstanceproc.sh
@@ -229,7 +229,7 @@ printclass()
echo "$3 e$1 = new OptionsWidgetInstanceEntry;" >> $TARGET
echo -n "$3 e$1->createProc = &class$2" >> $TARGET
echo "_createInstanceProc;" >> $TARGET
- echo "$3 e$1->pWidget = 0;" >> $TARGET
+ echo "$3 e$1->pWidget = nullptr;" >> $TARGET
echo "$3 e$1->szClassName = g_szClassName_$2;" >> $TARGET
echo "$3 e$1->eIcon = KVI_OPTIONS_WIDGET_ICON_$2;" >> $TARGET
@@ -288,7 +288,7 @@ addchildren()
NEXTLEVEL=`expr $1 + 1`
addchildren $NEXTLEVEL $achild "$3 "
else
- echo "$3 e$1->pChildList = 0;" >> $TARGET
+ echo "$3 e$1->pChildList = nullptr;" >> $TARGET
fi
done
fi
@@ -316,7 +316,7 @@ void OptionsInstanceManager::deleteInstanceTree(KviPointerList<OptionsWidgetInst
{
disconnect(pEntry->pWidget,SIGNAL(destroyed()),this,SLOT(widgetDestroyed()));
delete pEntry->pWidget->parent();
- pEntry->pWidget = 0;
+ pEntry->pWidget = nullptr;
} else {
qDebug("Ops...i have deleted the options dialog ?");
}
@@ -337,14 +337,14 @@ OptionsInstanceManager::~OptionsInstanceManager()
void OptionsInstanceManager::cleanup(KviModule *)
{
deleteInstanceTree(m_pInstanceTree);
- m_pInstanceTree = 0;
+ m_pInstanceTree = nullptr;
}
void OptionsInstanceManager::widgetDestroyed()
{
OptionsWidgetInstanceEntry * pEntry = findInstanceEntry(sender(),m_pInstanceTree);
if(pEntry)
- pEntry->pWidget = 0;
+ pEntry->pWidget = nullptr;
if(g_iOptionWidgetInstances > 0)
g_iOptionWidgetInstances--;
@@ -353,7 +353,7 @@ void OptionsInstanceManager::widgetDestroyed()
KviOptionsWidget * OptionsInstanceManager::getInstance(OptionsWidgetInstanceEntry * pEntry, QWidget * pPar)
{
if(!pEntry)
- return NULL;
+ return nullptr;
#if 0
if(pEntry->pWidget)
@@ -363,7 +363,7 @@ KviOptionsWidget * OptionsInstanceManager::getInstance(OptionsWidgetInstanceEntr
QWidget * pOldPar = (QWidget *)pEntry->pWidget->parent();
pEntry->pWidget->setParent(pPar);
pOldPar->deleteLater();
- pEntry->pWidget = 0;
+ pEntry->pWidget = nullptr;
}
}
#endif
diff --git a/src/modules/popupeditor/PopupEditorWindow.h b/src/modules/popupeditor/PopupEditorWindow.h
index 9384e9e72..62228bdec 100644
--- a/src/modules/popupeditor/PopupEditorWindow.h
+++ b/src/modules/popupeditor/PopupEditorWindow.h
@@ -104,7 +104,7 @@ public:
protected:
// theItem is the item above the first item that has to be inserted
- void populateMenu(KviKvsPopupMenu * pop, PopupTreeWidgetItem * par, PopupTreeWidgetItem * theItem = 0);
+ void populateMenu(KviKvsPopupMenu * pop, PopupTreeWidgetItem * par, PopupTreeWidgetItem * theItem = nullptr);
void saveLastSelectedItem();
void addItemToMenu(KviKvsPopupMenu * pop, PopupTreeWidgetItem * par);
PopupTreeWidgetItem * newItem(PopupTreeWidgetItem * par, PopupTreeWidgetItem * after, PopupTreeWidgetItem::Type t);
diff --git a/src/modules/reguser/RegisteredUsersDialog.h b/src/modules/reguser/RegisteredUsersDialog.h
index f066a21f5..a949ae16d 100644
--- a/src/modules/reguser/RegisteredUsersDialog.h
+++ b/src/modules/reguser/RegisteredUsersDialog.h
@@ -54,7 +54,7 @@ signals:
class RegisteredUsersDialogItemDelegate : public QStyledItemDelegate
{
public:
- RegisteredUsersDialogItemDelegate(KviRegisteredUsersListView * pWidget = 0)
+ RegisteredUsersDialogItemDelegate(KviRegisteredUsersListView * pWidget = nullptr)
: QStyledItemDelegate(pWidget){};
~RegisteredUsersDialogItemDelegate(){};
QSize sizeHint(const QStyleOptionViewItem & option, const QModelIndex & index) const override;
@@ -123,7 +123,7 @@ class RegisteredUsersDialog : public QWidget
{
Q_OBJECT
public:
- RegisteredUsersDialog(QWidget * par = 0);
+ RegisteredUsersDialog(QWidget * par = nullptr);
~RegisteredUsersDialog();
public:
diff --git a/src/modules/reguser/RegistrationWizard.h b/src/modules/reguser/RegistrationWizard.h
index bfbd380c9..a3cd710ed 100644
--- a/src/modules/reguser/RegistrationWizard.h
+++ b/src/modules/reguser/RegistrationWizard.h
@@ -43,7 +43,7 @@ class RegistrationWizard : public KviTalWizard
{
Q_OBJECT
public:
- RegistrationWizard(const QString & startMask, KviRegisteredUserDataBase * db = 0, QWidget * par = 0, bool bModal = false);
+ RegistrationWizard(const QString & startMask, KviRegisteredUserDataBase * db = nullptr, QWidget * par = nullptr, bool bModal = false);
~RegistrationWizard();
KviRegisteredUserDataBase * m_pDb;
diff --git a/src/modules/rijndael/Rijndael.h b/src/modules/rijndael/Rijndael.h
index 6905397e9..95331c07a 100644
--- a/src/modules/rijndael/Rijndael.h
+++ b/src/modules/rijndael/Rijndael.h
@@ -145,31 +145,31 @@ protected:
public:
// Initializes the crypt session
// Returns RIJNDAEL_SUCCESS or an error code
- int init(Mode mode, Direction dir, const UINT8 * key, KeyLength keyLen, UINT8 * initVector = 0);
+ int init(Mode mode, Direction dir, const UINT8 * key, KeyLength keyLen, UINT8 * initVector = nullptr);
// Input len is in BITS!
// Encrypts inputLen / 128 blocks of input and puts it in outBuffer
// outBuffer must be at least inputLen / 8 bytes long.
// Returns the encrypted buffer length in BITS or an error code < 0 in case of error
- int blockEncrypt(const UINT8 * input, int inputLen, UINT8 * outBuffer, UINT8 * initVector = 0);
+ int blockEncrypt(const UINT8 * input, int inputLen, UINT8 * outBuffer, UINT8 * initVector = nullptr);
// Input len is in BYTES!
// outBuffer must be at least inputLen + 16 bytes long
// Returns the encrypted buffer length in BYTES or an error code < 0 in case of error
- int padEncrypt(const UINT8 * input, int inputOctets, UINT8 * outBuffer, UINT8 * initVector = 0);
+ int padEncrypt(const UINT8 * input, int inputOctets, UINT8 * outBuffer, UINT8 * initVector = nullptr);
// Input len is in BITS!
// outBuffer must be at least inputLen / 8 bytes long
// Returns the decrypted buffer length in BITS and an error code < 0 in case of error
- int blockDecrypt(const UINT8 * input, int inputLen, UINT8 * outBuffer, UINT8 * initVector = 0);
+ int blockDecrypt(const UINT8 * input, int inputLen, UINT8 * outBuffer, UINT8 * initVector = nullptr);
// Input len is in BYTES!
// outBuffer must be at least inputLen bytes long
// Returns the decrypted buffer length in BYTES and an error code < 0 in case of error
- int padDecrypt(const UINT8 * input, int inputOctets, UINT8 * outBuffer, UINT8 * initVector = 0);
+ int padDecrypt(const UINT8 * input, int inputOctets, UINT8 * outBuffer, UINT8 * initVector = nullptr);
protected:
void keySched(UINT8 key[_MAX_KEY_COLUMNS][4]);
void keyEncToDec();
void encrypt(const UINT8 a[16], UINT8 b[16]);
void decrypt(const UINT8 a[16], UINT8 b[16]);
- void updateInitVector(UINT8 * initVector = 0);
+ void updateInitVector(UINT8 * initVector = nullptr);
};
#endif // COMPILE_CRYPT_SUPPORT
diff --git a/src/modules/setup/SetupWizard.cpp b/src/modules/setup/SetupWizard.cpp
index 00519dfe2..8cef633e1 100644
--- a/src/modules/setup/SetupWizard.cpp
+++ b/src/modules/setup/SetupWizard.cpp
@@ -806,7 +806,7 @@ void SetupWizard::makeLink()
0, KEY_QUERY_VALUE, &hCU)
== ERROR_SUCCESS)
{
- RegQueryValueEx(hCU, TEXT("Desktop"), NULL, &lpType,
+ RegQueryValueEx(hCU, TEXT("Desktop"), nullptr, &lpType,
(unsigned char *)&szLink, &ulSize);
RegCloseKey(hCU);
}
@@ -819,13 +819,13 @@ void SetupWizard::makeLink()
szKvircExec.append("\\kvirc.exe");
// Trigger a horrible machinery
- CoInitialize(NULL); // we need COM+OLE
+ CoInitialize(nullptr); // we need COM+OLE
// Fiddle with an obscure shell interface
IShellLink * psl;
// Get a pointer to the IShellLink interface: this is kinda ugly :)
- if(CoCreateInstance(CLSID_ShellLink, NULL, CLSCTX_INPROC_SERVER,
+ if(CoCreateInstance(CLSID_ShellLink, nullptr, CLSCTX_INPROC_SERVER,
IID_IShellLink, (void **)&psl)
== S_OK)
{
diff --git a/src/modules/sharedfileswindow/SharedFilesWindow.h b/src/modules/sharedfileswindow/SharedFilesWindow.h
index fd9fd6dee..96de53ef3 100644
--- a/src/modules/sharedfileswindow/SharedFilesWindow.h
+++ b/src/modules/sharedfileswindow/SharedFilesWindow.h
@@ -57,7 +57,7 @@ class SharedFileEditDialog : public QDialog
{
Q_OBJECT
public:
- SharedFileEditDialog(QWidget * par, KviSharedFile * f = 0);
+ SharedFileEditDialog(QWidget * par, KviSharedFile * f = nullptr);
virtual ~SharedFileEditDialog();
QDateTimeEdit * m_pExpireDateTimeEdit;
diff --git a/src/modules/snd/libkvisnd.cpp b/src/modules/snd/libkvisnd.cpp
index 18f0c599b..4c56ab380 100644
--- a/src/modules/snd/libkvisnd.cpp
+++ b/src/modules/snd/libkvisnd.cpp
@@ -215,7 +215,7 @@ void KviSoundPlayer::detectSoundSystem()
#else
#ifdef COMPILE_ESD_SUPPORT
esd_format_t format = ESD_BITS16 | ESD_STREAM | ESD_PLAY | ESD_MONO;
- int esd_fd = esd_play_stream(format, 8012, NULL, "kvirc");
+ int esd_fd = esd_play_stream(format, 8012, nullptr, "kvirc");
if(esd_fd >= 0)
{
KVI_OPTION_STRING(KviOption_stringSoundSystem) = "esd";
@@ -645,7 +645,7 @@ KviEsdSoundThread::~KviEsdSoundThread()
void KviEsdSoundThread::play()
{
// ESD has a really nice API
- if(!esd_play_file(NULL, m_szFileName.toUtf8().data(), 1)) // this is sync.. FIXME: it can't be stopped!
+ if(!esd_play_file(nullptr, m_szFileName.toUtf8().data(), 1)) // this is sync.. FIXME: it can't be stopped!
qDebug("Could not play sound %s! [ESD]", m_szFileName.toUtf8().data());
}
diff --git a/src/modules/term/TermWidget.cpp b/src/modules/term/TermWidget.cpp
index 57ff5b65b..304daea00 100644
--- a/src/modules/term/TermWidget.cpp
+++ b/src/modules/term/TermWidget.cpp
@@ -55,8 +55,8 @@ TermWidget::TermWidget(QWidget * par, bool bIsStandalone)
g_pTermWidgetList.insert(this);
m_bIsStandalone = bIsStandalone;
- m_pKonsolePart = 0;
- m_pKonsoleWidget = 0;
+ m_pKonsolePart = nullptr;
+ m_pKonsoleWidget = nullptr;
if(bIsStandalone)
{
@@ -71,9 +71,9 @@ TermWidget::TermWidget(QWidget * par, bool bIsStandalone)
}
else
{
- m_pHBox = 0;
- m_pTitleLabel = 0;
- m_pCloseButton = 0;
+ m_pHBox = nullptr;
+ m_pTitleLabel = nullptr;
+ m_pCloseButton = nullptr;
}
setFrameStyle(QFrame::Sunken | QFrame::Panel);
@@ -138,8 +138,8 @@ void TermWidget::closeClicked()
void TermWidget::konsoleDestroyed()
{
- m_pKonsoleWidget = 0;
- m_pKonsolePart = 0;
+ m_pKonsoleWidget = nullptr;
+ m_pKonsolePart = nullptr;
hide();
QTimer::singleShot(0, this, SLOT(autoClose()));
}
diff --git a/src/modules/term/TermWindow.cpp b/src/modules/term/TermWindow.cpp
index 93f17852d..9ee745226 100644
--- a/src/modules/term/TermWindow.cpp
+++ b/src/modules/term/TermWindow.cpp
@@ -42,7 +42,7 @@ TermWindow::TermWindow(const char * name)
: KviWindow(KviWindow::Terminal, name)
{
g_pTermWindowList.insert(this);
- m_pTermWidget = 0;
+ m_pTermWidget = nullptr;
m_pTermWidget = new TermWidget(this);
}
diff --git a/src/modules/theme/ThemeFunctions.h b/src/modules/theme/ThemeFunctions.h
index f4b68fdf9..af6ef10de 100644
--- a/src/modules/theme/ThemeFunctions.h
+++ b/src/modules/theme/ThemeFunctions.h
@@ -35,7 +35,7 @@
namespace ThemeFunctions
{
- bool installThemePackage(const QString & szThemePackageFileName, QString & szError, QWidget * pDialogParent = 0);
+ bool installThemePackage(const QString & szThemePackageFileName, QString & szError, QWidget * pDialogParent = nullptr);
void getThemeHtmlDescription(
QString & szBuffer,
@@ -49,7 +49,7 @@ namespace ThemeFunctions
const QString & szThemeThemeEngineVersion,
const QPixmap & pixScreenshot,
int iUniqueIndexInDocument = 0,
- KviHtmlDialogData * hd = 0);
+ KviHtmlDialogData * hd = nullptr);
bool makeKVIrcScreenshot(const QString & szSavePngFilePath, bool bMaximizeFrame = false);
diff --git a/src/modules/theme/WebThemeInterfaceDialog.h b/src/modules/theme/WebThemeInterfaceDialog.h
index 42c906540..3e840daee 100644
--- a/src/modules/theme/WebThemeInterfaceDialog.h
+++ b/src/modules/theme/WebThemeInterfaceDialog.h
@@ -34,7 +34,7 @@ class WebThemeInterfaceDialog : public KviWebPackageManagementDialog
{
Q_OBJECT
public:
- WebThemeInterfaceDialog(QWidget * par = 0);
+ WebThemeInterfaceDialog(QWidget * par = nullptr);
~WebThemeInterfaceDialog();
private:
diff --git a/src/modules/torrent/TorrentInterface.h b/src/modules/torrent/TorrentInterface.h
index 276fd46d6..31329b0b0 100644
--- a/src/modules/torrent/TorrentInterface.h
+++ b/src/modules/torrent/TorrentInterface.h
@@ -136,7 +136,7 @@ public:
_interfaceclass##Descriptor::_interfaceclass##Descriptor() \
: TorrentInterfaceDescriptor() \
{ \
- m_pInstance = 0; \
+ m_pInstance = nullptr; \
m_szName = _name; \
m_szDescription = _description; \
} \
diff --git a/src/modules/url/libkviurl.h b/src/modules/url/libkviurl.h
index 59220f27b..cb14edac7 100644
--- a/src/modules/url/libkviurl.h
+++ b/src/modules/url/libkviurl.h
@@ -109,7 +109,7 @@ class BanFrame : public QFrame
{
Q_OBJECT
public:
- BanFrame(QWidget * parent = 0, const char * name = 0, bool banEnable = false);
+ BanFrame(QWidget * parent = nullptr, const char * name = nullptr, bool banEnable = false);
~BanFrame();
void saveBans(KviConfigurationFile * cfg);
diff --git a/src/modules/window/UserWindow.h b/src/modules/window/UserWindow.h
index ab8901db8..a7a8cd597 100644
--- a/src/modules/window/UserWindow.h
+++ b/src/modules/window/UserWindow.h
@@ -37,7 +37,7 @@ public:
};
public:
- UserWindow(const char * pcName, QString & szIcon, KviConsoleWindow * pConsole = 0, int iCreationFlags = 0);
+ UserWindow(const char * pcName, QString & szIcon, KviConsoleWindow * pConsole = nullptr, int iCreationFlags = 0);
~UserWindow();
protected:
diff --git a/src/modules/mediaplayer/MpWinampInterface.cpp b/src/modules/mediaplayer/MpWinampInterface.cpp
index 0d08cc4b5..875fc8838 100644
--- a/src/modules/mediaplayer/MpWinampInterface.cpp
+++ b/src/modules/mediaplayer/MpWinampInterface.cpp
@@ -83,13 +83,13 @@
// ** (requires Winamp 2.04+, only usable from plug-ins (not external apps))
// ** char *name=SendMessage(hwnd_winamp,WM_WA_IPC,index,IPC_GETPLAYLISTFILE);
// ** IPC_GETPLAYLISTFILE gets the filename of the playlist entry [index].
// ** returns a pointer to it. returns NULL on error.
#define IPC_GETPLAYLISTTITLE 212
// * (requires Winamp 2.04+, only usable from plug-ins (not external apps))
// ** char *name=SendMessage(hwnd_winamp,WM_WA_IPC,index,IPC_GETPLAYLISTTITLE);
// ** IPC_GETPLAYLISTTITLE gets the title of the playlist entry [index].
// ** returns a pointer to it. returns NULL on error.
#define IPC_GET_SHUFFLE 250
// ** val=SendMessage(hwnd_winamp,WM_WA_IPC,0,IPC_GET_SHUFFLE);
@@ -131,7 +131,7 @@
// ** cds.dwData = IPC_PLAYFILE;
// ** cds.lpData = (void *) "file.mp3";
// ** cds.cbData = strlen((char *) cds.lpData)+1; // include space for null char
-// ** SendMessage(hwnd_winamp,WM_COPYDATA,(WPARAM)NULL,(LPARAM)&cds);
+// ** SendMessage(hwnd_winamp,WM_COPYDATA,(WPARAM)nullptr,(LPARAM)&cds);
// **
// ** This will play the file "file.mp3".
@@ -165,8 +165,7 @@
static QTextCodec * mediaplayer_get_codec()
{
- QTextCodec * pCodec = 0;
- pCodec = QTextCodec::codecForName(KVI_OPTION_STRING(KviOption_stringWinampTextEncoding).toUtf8());
+ QTextCodec * pCodec = QTextCodec::codecForName(KVI_OPTION_STRING(KviOption_stringWinampTextEncoding).toUtf8());
if(!pCodec)
pCodec = QTextCodec::codecForLocale();
@@ -175,7 +174,7 @@ static QTextCodec * mediaplayer_get_codec()
static HWND find_winamp(KviWinampInterface * i)
{
- HWND hWnd = FindWindow(TEXT("Winamp v1.x"), NULL);
+ HWND hWnd = FindWindow(TEXT("Winamp v1.x"), nullptr);
if(!hWnd)
{
// try to start the process ?
@@ -385,7 +384,7 @@ bool KviWinampInterface::playMrl(const QString & mrl)
cds.dwData = IPC_PLAYFILE;
cds.lpData = (void *)szMrl.ptr();
cds.cbData = szMrl.len() + 1; // include space for null char
- SendMessage(hWinamp, WM_COPYDATA, (WPARAM)NULL, (LPARAM)&cds);
+ SendMessage(hWinamp, WM_COPYDATA, (WPARAM)nullptr, (LPARAM)&cds);
return true;
}
return false;
@@ -429,11 +428,11 @@ bool KviWinampInterface::jumpTo(kvs_int_t & iPos)
bool KviWinampInterface::hide()
{
HWND hWinamp = find_winamp(this);
- HWND hWinampPE = FindWindow(TEXT("Winamp PE"), NULL); /*Playlist*/
- HWND hWinampEQ = FindWindow(TEXT("Winamp EQ"), NULL); /*Equalizer*/
- HWND hWinampMB = FindWindow(TEXT("Winamp MB"), NULL); /*MiniBrowser*/
- HWND hWinampGen = FindWindow(TEXT("Winamp Gen"), NULL); /*Library*/
- HWND hWinampVideo = FindWindow(TEXT("Winamp Video"), NULL); /*Video*/
+ HWND hWinampPE = FindWindow(TEXT("Winamp PE"), nullptr); /*Playlist*/
+ HWND hWinampEQ = FindWindow(TEXT("Winamp EQ"), nullptr); /*Equalizer*/
+ HWND hWinampMB = FindWindow(TEXT("Winamp MB"), nullptr); /*MiniBrowser*/
+ HWND hWinampGen = FindWindow(TEXT("Winamp Gen"), nullptr); /*Library*/
+ HWND hWinampVideo = FindWindow(TEXT("Winamp Video"), nullptr); /*Video*/
if(hWinamp)
{
ShowWindow(hWinamp, SW_HIDE);
@@ -83,13 +83,13 @@
// ** char *name=SendMessage(hwnd_winamp,WM_WA_IPC,index,IPC_GETPLAYLISTFILE);
// ** IPC_GETPLAYLISTFILE gets the filename of the playlist entry [index].
-// ** returns a pointer to it. returns NULL on error.
+// ** returns a pointer to it. returns nullptr on error.
#define IPC_GETPLAYLISTTITLE 212
// * (requires Winamp 2.04+, only usable from plug-ins (not external apps))
@@ -83,13 +83,13 @@
// ** char *name=SendMessage(hwnd_winamp,WM_WA_IPC,index,IPC_GETPLAYLISTTITLE);
// ** IPC_GETPLAYLISTTITLE gets the title of the playlist entry [index].
-// ** returns a pointer to it. returns NULL on error.
+// ** returns a pointer to it. returns nullptr on error.
#define IPC_GET_SHUFFLE 250
// ** val=SendMessage(hwnd_winamp,WM_WA_IPC,0,IPC_GET_SHUFFLE);